sqlobject.tests.test_inheritance module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_inheritance module

class `sqlobject.tests.test_inheritance.` `Sub`(**kw)

  Bases: `sqlobject.tests.test_inheritance.Super`

  `j` = sub
  property `name2`
  `q` = sub
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childName` = None
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_inheritance.Sub`

    `table` = 'sub'

class `sqlobject.tests.test_inheritance.` `Super`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = super
  property `name`
  `q` = super
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_inheritance.Super`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'super'

`sqlobject.tests.test_inheritance.` `test_sub`()

`sqlobject.tests.test_inheritance.` `test_super`()